/**
 * Measure coverage and save report to file.
 * @memberof module:ap-covering/lib
 * @function measureCoverage
 * @param {string} script - JavaScript script to measure
 * @param {string[]} scriptArgs - Arguments to pass script.
 * @param {object} {object} [options] - Optional settings.
 * @param {string} [options.dir='coverage'] - Directory path to save.
 */

"use strict";

const argx = require('argx'),
    execcli = require('execcli');

/** @lends measureCoverage */
function measureCoverage(script, scriptArgs, options, callback) {
    let args = argx(arguments);
    callback = args.pop('function') || argx.noop;


    script = args.shift('string');
    scriptArgs = [].concat(args.shift('string|array') || []);
    options = args.pop('object') || {};

    let spawnArgs = ['cover', '--dir', options.dir || 'coverage', script, '--'].concat(scriptArgs);
    exports.istanbul(spawnArgs, callback);
}

exports.istanbul = function (args, callback) {
    execcli('istanbul', args, {
        notfound: 'try `npm install istanbul -g`'
    }, callback)
};

module.exports = measureCoverage;


